@@ -7,7 +7,7 @@ import PIL.ImageDraw
 
 
 # You may think dynamic attribute attachment is a more pythonic solution, but,
-# at least here, actually a more problematic one.
+# at least here, actually a more buggy one.
 class Page(object):
     """A simple wrapper for Pillow Image Object"""
 
@@ -26,18 +26,14 @@ class Page(object):
     def draw(self):
         return PIL.ImageDraw.Draw(self.image)
 
-    @property
     def matrix(self):
         return self.image.load()
 
-    @property
     def size(self) -> Tuple[int, int]:
         return self.image.size
 
-    @property
     def width(self) -> int:
         return self.image.width
 
-    @property
     def height(self) -> int:
         return self.image.height
